@@ -1,14 +1,16 @@
-/* 07mar12abu
+/* 12oct12abu
  * (c) Software Lab. Alexander Burger
  */
 
 var FormReq = false;
 var HintReq = false;
+var LispReq = false;
 var Hint, Hints, Item, Beg, End;
 
 try {
    FormReq = new XMLHttpRequest();
    HintReq = new XMLHttpRequest();
+   LispReq = new XMLHttpRequest();
    FormReq.upload.addEventListener("progress", dropProgress, false);
    FormReq.upload.addEventListener("load", dropLoad, false);
 }
@@ -408,7 +410,10 @@ function hintKey(field, event, tok, coy) {
          data += "&*Form=" + fld.value;
    }
    try {HintReq.send(data);}
-   catch (e) {HintReq.abort();}
+   catch (e) {
+      HintReq.abort();
+      return true;
+   }
    return (event.keyCode != 45);  // INS
 }
 
@@ -461,3 +466,22 @@ function hintOff(i) {
    s.background = "white";
    s.color= "black";
 }
+
+/*** Lisp calls ***/
+function lisp(url) {
+   if (!LispReq)
+      return true;
+   if (arguments.length > 1) {
+      url += "?" + arguments[1];  // arguments should be properly encoded
+      for (var i = 2; i < arguments.length; ++i)
+         url += "&" + arguments[i];
+   }
+   try {LispReq.open("GET", url);}
+   catch (e) {return true;}
+   try {LispReq.send(null);}
+   catch (e) {
+      LispReq.abort();
+      return true;
+   }
+   return false;
+}
